@@ -1,8 +1,8 @@
 import times
-from functools import total_ordering
 from .connections import get_current_connection
 from .job import Job
 from .exceptions import NoSuchJobError, UnpickleError, InvalidJobOperationError
+from .compat import total_ordering
 
 
 def get_failed_queue(connection=None):
@@ -40,7 +40,7 @@ class Queue(object):
         if not queue_key.startswith(prefix):
             raise ValueError('Not a valid RQ queue key: %s' % (queue_key,))
         name = queue_key[len(prefix):]
-        return Queue(name, connection=connection)
+        return cls(name, connection=connection)
 
     def __init__(self, name='default', default_timeout=None, connection=None):
         if connection is None:
@@ -154,7 +154,7 @@ class Queue(object):
         return self.connection.lpop(self.key)
 
     @classmethod
-    def lpop(cls, queue_keys, blocking):
+    def lpop(cls, queue_keys, blocking, connection=None):
         """Helper method.  Intermediate method to abstract away from some
         Redis API details, where LPOP accepts only a single key, whereas BLPOP
         accepts multiple.  So if we want the non-blocking LPOP, we need to
@@ -163,13 +163,14 @@ class Queue(object):
         Until Redis receives a specific method for this, we'll have to wrap it
         this way.
         """
-        conn = get_current_connection()
+        if connection is None:
+            connection = get_current_connection()
         if blocking:
-            queue_key, job_id = conn.blpop(queue_keys)
+            queue_key, job_id = connection.blpop(queue_keys)
             return queue_key, job_id
         else:
             for queue_key in queue_keys:
-                blob = conn.lpop(queue_key)
+                blob = connection.lpop(queue_key)
                 if blob is not None:
                     return queue_key, blob
             return None
@@ -205,11 +206,11 @@ class Queue(object):
         any of the queues, or returns None.
         """
         queue_keys = [q.key for q in queues]
-        result = cls.lpop(queue_keys, blocking)
+        result = cls.lpop(queue_keys, blocking, connection=connection)
         if result is None:
             return None
         queue_key, job_id = result
-        queue = Queue.from_queue_key(queue_key, connection=connection)
+        queue = cls.from_queue_key(queue_key, connection=connection)
         try:
             job = Job.fetch(job_id, connection=connection)
         except NoSuchJobError:
